@@ -116,8 +116,11 @@ class FancyProgressBar(object):
                 gtk.ICON_SIZE_LARGE_TOOLBAR)
         self.cancel_button = gtk.ToolButton(image)
         self.hbox_animation_actor = gtk.HBox()
-        self.hbox_animation_actor.pack_start(self.progress_bar)
-        self.hbox_animation_actor.pack_start(self.cancel_button, False)
+        self.hbox_inner = gtk.HBox()
+        self.hbox_animation_actor.pack_start(self.hbox_inner)
+        self.hbox_animation_actor.child_set(self.hbox_inner, 'padding', 12)
+        self.hbox_inner.pack_start(self.progress_bar)
+        self.hbox_inner.pack_start(self.cancel_button, False)
         self.animation_actor = hildon.AnimationActor()
         self.animation_actor.set_parent(self.parent)
         self.animation_actor.add(self.hbox_animation_actor)
